# Beijing Netitest Technology Co., Ltd.
Beijing Netitest Technology Co., Ltd. is a leading Chinese manufacturer specializing in network testing instruments. The company has independently innovated the Supernova/DarkBird L2-7 full-stack network testing platform, which comprehensively covers network, security, industrial control, and application testing. It holds particularly strong competitive advantages in Cloud, AI networks, NTN, and XinChuang testing.

# Python Object-Oriented Library to Automate Netitest Network Testing Instruments

## Functionality
The current version supports the following management and operations:

- Connect and manage network testing instruments of Netitest Technology Co., Ltd. like Supernova or DarkBird
- Create and update project/case/object/resource
- Load/Save json configuration, Configure Network and Get/Set attributes 
- Start/Monitor/Stop test case
- Generate/Download statistics in various formats, including PDF, Word, and HTML.

## Installation

pip install pyntsc

**Prerequisite**

- Supernova or DarkBird Network Testing Instruments

## Getting started
Under examples you will find some basic samples. See inside for more info.

## Source Code
https://github.com/netitest/pyntsc

## Documentation
http://www.netitest.com

## Contact
Any question or feature request at hfli@netitest.com

